==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeXPathNSResolver.h <==
// class gnu.xml.libxmlj.dom.GnomeXPathNSResolver

// class file dependencies
// @dep_class 1d93ffb6ee64df83 gnu_xml_libxmlj_dom_GnomeXPathNSResolver
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeXPathNSResolver_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeXPathNSResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtable	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$method$_init$ea4cfa151ae11b7c(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vmethods {
	struct _jc_java_lang_String$object	*(*lookupNamespaceURI$14d569e8938f97a2)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vmethods	gnu_xml_libxmlj_dom_GnomeXPathNSResolver;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_refs {
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_refs	gnu_xml_libxmlj_dom_GnomeXPathNSResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeXPathNSResolver;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object {
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeXPathNSResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeXPathNSResolver_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeXPathNSResolver.h <==
// class gnu.xml.libxmlj.dom.GnomeXPathNSResolver

// class file dependencies
// @dep_class 1d93ffb6ee64df83 gnu_xml_libxmlj_dom_GnomeXPathNSResolver
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeXPathNSResolver_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeXPathNSResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$refs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtable	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$method$_init$ea4cfa151ae11b7c(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vmethods {
	struct _jc_java_lang_String$object	*(*lookupNamespaceURI$14d569e8938f97a2)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vmethods	gnu_xml_libxmlj_dom_GnomeXPathNSResolver;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_refs {
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_refs	gnu_xml_libxmlj_dom_GnomeXPathNSResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeXPathNSResolver;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$object {
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$vtype _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeXPathNSResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeXPathNSResolver$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeXPathNSResolver_H_ */
